@@ -3,9 +3,17 @@ Module that contains various strings that are used in tests
 """
 from collections import namedtuple
 from datetime import datetime
-
+from unittest import skipIf
 import os
 
+try:
+    import pyhdf
+except ImportError:
+    # Disable all these tests if pandas is not installed.
+    pyhdf = None
+
+skip_pyhdf = skipIf(pyhdf is None, 'Test(s) require "pandas", which is not available.')
+
 # A dictionary of test file tuples indexed by characteristic name
 cis_test_files = {}
 
@@ -29,10 +37,14 @@ TestFileTestData = namedtuple('TestFile',
 data_directory = os.environ.get("CIS_DATA_HOME", os.path.dirname(__file__))
 
 
+def escape_colons(filename):
+    if os.name == 'nt':
+        filename = filename.replace(':', '\:')
+    return filename
+
+
 def make_pathname(filename):
     path = os.path.join(data_directory, filename)
-    if os.name == 'nt':
-        path = path.replace(':', '\:')
     return path
 
 
@@ -89,6 +101,7 @@ modis_myd06_l2_filenames = [make_pathname("MYD06_L2.A2011100.1720.051.2011102130
 modis_myd06_l2_variable = "Surface_Temperature"
 
 valid_modis_l3_filename = make_pathname("MOD08_E3.A2010009.005.2010026072315.hdf")
+valid_modis_l3_filename2 = make_pathname("MOD08_E3.A2010017.005.2010029140340.hdf")
 valid_modis_l3_variable = "Solar_Zenith_Std_Deviation_Mean"
 cis_test_files["modis_L3"] = TestFileTestData(
     master_filename=valid_modis_l3_filename,
@@ -149,7 +162,7 @@ cis_test_files["Aerosol_CCI"] = TestFileTestData(
     lon_min=-22.25,
     lon_max=160.48,
     valid_vars_count=32,
-    all_variable_names=None,
+    all_variable_names=[valid_aerosol_cci_variable, valid_aerosol_cci_variable_2],
     data_variable_name=valid_aerosol_cci_variable,
     data_variable_standard_name='atmosphere_optical_thickness_due_to_aerosol',
     data_variable_properties={}
@@ -395,6 +408,9 @@ cis_test_files["ascii"] = TestFileTestData(
     data_variable_properties={}
 )
 
+netcdf_cf_compliant_ranges_filename = make_pathname("netcdf_file_with_valid_ranges.nc")
+netcdf_cf_compliant_ranges_vars = ["LON_502", "SO4_1950", "CL_1944"]
+
 valid_NCAR_NetCDF_RAF_filename = make_pathname("RF04.20090114.192600_035100.PNI.nc")
 valid_NCAR_NetCDF_RAF_variable = 'ATX'
 
@@ -410,7 +426,7 @@ cis_test_files["NCAR_NetCDF_RAF"] = TestFileTestData(
     lon_max=62,
     #    alt_min=20.5,
     #    alt_max=3678.5,
-    valid_vars_count=117,
+    valid_vars_count=121,
     all_variable_names=None,
     data_variable_name='ATX',
     data_variable_standard_name="ATX",
@@ -423,6 +439,27 @@ cis_test_files["NCAR_NetCDF_RAF"] = TestFileTestData(
 valid_GASSP_not_entirely_correct_filename = make_pathname("ACE1_aero_an.nc")
 valid_GASSP_not_entirely_correct_variable = 'TIM_627'
 
+cis_test_files["GASSP_aux_coord"] = TestFileTestData(
+    master_filename=make_pathname("ACE1_NSD_RF06_11081995163707_11081995210628.nc"),
+    file_format="NetCDF/GASSP/2.0",
+    product_name="NCAR_NetCDF_RAF",
+    start_datetime=datetime(1995, 11, 8, 16, 37, 0o7),
+    end_datetime=datetime(1995, 11, 8, 21, 6, 28),
+    lat_min=4.85591,
+    lat_max=21.3232,
+    lon_min=-157.946,
+    lon_max=-155.102,
+    #    alt_min=20.5,
+    #    alt_max=3678.5,
+    all_variable_names=["NUMDIST_DMA_OPC", "AREADIST_DMA_OPC", "VOLDIST_DMA_OPC",],
+    valid_vars_count=11,
+    data_variable_name='NUMDIST_DMA_OPC',
+    data_variable_standard_name='NUMDIST_DMA_OPC',
+    data_variable_properties={
+        "units": "#/cm3",
+        "missing_value": -32767}
+)
+
 valid_GASSP_aeroplane_filename = make_pathname("SP2_mrg60_NP3_20060927_R1.ict.nc")
 valid_GASSP_aeroplane_vars = ['BC_ng_kg', "BC_ng_m3", "UTC_mid", "GpsAlt", "GpsLat", "GpsLon"]
 valid_GASSP_aeroplane_variable = valid_GASSP_aeroplane_vars[0]
@@ -523,9 +560,9 @@ valid_hybrid_height_variable = 'mmrbc'
 # Has netCDF4 hierarchical groups
 valid_netcdf_groups_file = make_pathname('W_XX-EUMETSAT-Darmstadt_SOUNDING_and_SATELLITE_METOPB_and_'
                                          'GOME_C_EUMP_20140405235655_08032_eps_t_pmap_l2.nc')
-valid_netcdf_groups_variable = 'AVHRR.Ch4CentralWavenumber'
+valid_netcdf_groups_variable = 'AVHRR/Ch4CentralWavenumber'
 valid_nested_groups_file = make_pathname('nested_groups.nc')
-valid_nested_groups_variable = 'group1.group2.var4'
+valid_nested_groups_variable = 'group1/group2/var4'
 
 invalid_filename = "invalidfilename"
 non_netcdf_file = make_pathname("notanetcdffile")
