@@ -16,6 +16,7 @@ from cis.time_util import convert_datetime_to_std_time
 def make_mock_cube(lat_dim_length=5, lon_dim_length=3, lon_range=None, alt_dim_length=0, pres_dim_length=0,
                    time_dim_length=0,
                    horizontal_offset=0, altitude_offset=0, pressure_offset=0, time_offset=0, data_offset=0,
+                   surf_pres_offset=0,
                    hybrid_ht_len=0, hybrid_pr_len=0, geopotential_height=False, dim_order=None, mask=False):
     """
     Makes a cube of any shape required, with coordinate offsets from the default available. If no arguments are
@@ -39,6 +40,7 @@ def make_mock_cube(lat_dim_length=5, lon_dim_length=3, lon_range=None, alt_dim_l
     :param pressure_offset: Offset from the default grid in pressure
     :param time_offset: Offset from the default grid in time
     :param data_offset: Offset from the default data values
+    :param surf_pres_offset: Offset for the optional surface pressure field
     :param hybrid_ht_len: Hybrid height grid length
     :param hybrid_pr_len: Hybrid pressure grid length
     :param geopotential_height: Include a geopotential height field when calcluting a hybrid pressure? (default False)
@@ -96,7 +98,7 @@ def make_mock_cube(lat_dim_length=5, lon_dim_length=3, lon_range=None, alt_dim_l
 
     if time_dim_length:
         t0 = datetime.datetime(1984, 8, 27)
-        times = np.array([t0 + datetime.timedelta(days=d + time_offset) for d in xrange(time_dim_length)])
+        times = np.array([t0 + datetime.timedelta(days=d + time_offset) for d in range(time_dim_length)])
         time_nums = convert_datetime_to_std_time(times)
         time_bounds = None
         if time_dim_length == 1:
@@ -153,7 +155,7 @@ def make_mock_cube(lat_dim_length=5, lon_dim_length=3, lon_range=None, alt_dim_l
                                   coord_map['hybrid_pr'])
         return_cube.add_aux_coord(
             iris.coords.AuxCoord(np.arange(lat_dim_length * lon_dim_length * time_dim_length, dtype='i8')
-                                 .reshape(lat_dim_length, lon_dim_length, time_dim_length) * 100000,
+                                 .reshape(lat_dim_length, lon_dim_length, time_dim_length) * 100000 + surf_pres_offset,
                                  "surface_air_pressure", units="Pa"),
             [coord_map['lat'], coord_map['lon'], coord_map['time']])
 
@@ -191,6 +193,21 @@ def make_dummy_2d_cube():
     return cube
 
 
+def make_dummy_2d_cube_with_circular_lon():
+    """
+        Makes a dummy cube filled with random datapoints of shape 19x36
+    """
+    from iris.cube import Cube
+    from iris.coords import DimCoord
+
+    latitude = DimCoord(np.arange(-90., 100., 10.), standard_name='latitude', units='degrees')
+    longitude = DimCoord(np.arange(0., 360., 10.), standard_name='longitude', units='degrees', circular=True)
+    cube = Cube(np.reshape(np.arange(19 * 36) + 1.0, (19, 36)),
+                dim_coords_and_dims=[(latitude, 0), (longitude, 1)])
+
+    return cube
+
+
 def make_dummy_2d_cube_with_small_offset_in_lat():
     """
         Makes a dummy cube filled with random datapoints of shape 19x36
@@ -199,8 +216,8 @@ def make_dummy_2d_cube_with_small_offset_in_lat():
     from iris.cube import Cube
     from iris.coords import DimCoord
 
-    latitude = DimCoord(range(-84, 106, 10), standard_name='latitude', units='degrees')
-    longitude = DimCoord(range(0, 360, 10), standard_name='longitude', units='degrees')
+    latitude = DimCoord(list(range(-84, 106, 10)), standard_name='latitude', units='degrees')
+    longitude = DimCoord(list(range(0, 360, 10)), standard_name='longitude', units='degrees')
     cube = Cube(numpy.random.rand(19, 36), dim_coords_and_dims=[(latitude, 0), (longitude, 1)])
 
     return cube
@@ -214,8 +231,8 @@ def make_dummy_2d_cube_with_small_offset_in_lon():
     from iris.cube import Cube
     from iris.coords import DimCoord
 
-    latitude = DimCoord(range(-85, 105, 10), standard_name='latitude', units='degrees')
-    longitude = DimCoord(range(1, 361, 10), standard_name='longitude', units='degrees')
+    latitude = DimCoord(list(range(-85, 105, 10)), standard_name='latitude', units='degrees')
+    longitude = DimCoord(list(range(1, 361, 10)), standard_name='longitude', units='degrees')
     cube = Cube(numpy.random.rand(19, 36), dim_coords_and_dims=[(latitude, 0), (longitude, 1)])
 
     return cube
@@ -229,8 +246,8 @@ def make_dummy_2d_cube_with_small_offset_in_lat_and_lon():
     from iris.cube import Cube
     from iris.coords import DimCoord
 
-    latitude = DimCoord(range(-84, 106, 10), standard_name='latitude', units='degrees')
-    longitude = DimCoord(range(1, 361, 10), standard_name='longitude', units='degrees')
+    latitude = DimCoord(list(range(-84, 106, 10)), standard_name='latitude', units='degrees')
+    longitude = DimCoord(list(range(1, 361, 10)), standard_name='longitude', units='degrees')
     cube = Cube(numpy.random.rand(19, 36), dim_coords_and_dims=[(latitude, 0), (longitude, 1)])
 
     return cube
@@ -254,8 +271,8 @@ def make_list_with_2_dummy_2d_cubes_where_verticies_are_in_cell_centres():
     from iris.cube import Cube
     from iris.coords import DimCoord
 
-    latitude = DimCoord(range(0, 10, 2), standard_name='latitude', units='degrees')
-    longitude = DimCoord(range(0, 10, 2), standard_name='longitude', units='degrees')
+    latitude = DimCoord(list(range(0, 10, 2)), standard_name='latitude', units='degrees')
+    longitude = DimCoord(list(range(0, 10, 2)), standard_name='longitude', units='degrees')
     cube1 = Cube(numpy.random.rand(5, 5), dim_coords_and_dims=[(latitude, 0), (longitude, 1)])
 
     checkerboard = numpy.zeros((5, 5))
@@ -461,7 +478,7 @@ def make_square_5x3_2d_cube_with_time(offset=0, time_offset=0):
     import datetime
 
     t0 = datetime.datetime(1984, 8, 27)
-    times = np.array([t0 + datetime.timedelta(days=d + time_offset) for d in xrange(7)])
+    times = np.array([t0 + datetime.timedelta(days=d + time_offset) for d in range(7)])
 
     time_nums = convert_datetime_to_std_time(times)
 
@@ -474,6 +491,47 @@ def make_square_5x3_2d_cube_with_time(offset=0, time_offset=0):
     return cube
 
 
+def make_square_5x3_2d_cube_with_scalar_time(time_offset=0):
+    """
+        Makes a well defined cube of shape 5x3 with data as follows
+        array([[1,2,3],
+               [4,5,6],
+               [7,8,9],
+               [10,11,12],
+               [13,14,15]])
+        and coordinates in latitude:
+            array([ -10, -5, 0, 5, 10 ])
+        longitude:
+            array([ -5, 0, 5 ])
+        time:
+            1984-08-27
+        time_bounds:
+            [1984-08-22, 1984-09-01]
+    """
+    import numpy as np
+    from iris.cube import Cube
+    from iris.coords import DimCoord
+    from cis.time_util import cis_standard_time_unit
+
+    t0 = datetime.datetime(1984, 8, 27)
+
+    time_nums = convert_datetime_to_std_time(t0 + datetime.timedelta(days=time_offset))
+
+    time = DimCoord(time_nums, standard_name='time',
+                    bounds=[convert_datetime_to_std_time(t0 - datetime.timedelta(days=5)),
+                            convert_datetime_to_std_time(t0 + datetime.timedelta(days=5))],
+                    units=cis_standard_time_unit)
+
+    latitude = DimCoord(np.arange(-10., 11., 5), var_name='lat', standard_name='latitude', units='degrees')
+    longitude = DimCoord(np.arange(-5., 6., 5), var_name='lon', standard_name='longitude', units='degrees')
+    data = np.reshape(np.arange(15) + 1.0, (5, 3))
+    cube = Cube(data, dim_coords_and_dims=[(latitude, 0), (longitude, 1)], var_name='dummy')
+
+    cube.add_aux_coord(time)
+
+    return cube
+
+
 def make_square_NxM_2d_cube_with_time(start_lat=-10, end_lat=10, lat_point_count=5,
                                       start_lon=-5, end_lon=5, lon_point_count=3,
                                       time_offset=0):
@@ -514,7 +572,7 @@ def make_square_NxM_2d_cube_with_time(start_lat=-10, end_lat=10, lat_point_count
     import datetime
 
     t0 = datetime.datetime(1984, 8, 27)
-    times = np.array([t0 + datetime.timedelta(days=d + time_offset) for d in xrange(7)])
+    times = np.array([t0 + datetime.timedelta(days=d + time_offset) for d in range(7)])
 
     time_nums = convert_datetime_to_std_time(times)
 
@@ -622,7 +680,7 @@ def make_dummy_1d_cube():
     from iris.cube import Cube
     from iris.coords import DimCoord
 
-    latitude = DimCoord(range(-85, 105, 10), standard_name='latitude', units='degrees')
+    latitude = DimCoord(list(range(-85, 105, 10)), standard_name='latitude', units='degrees')
     cube = Cube(numpy.random.rand(19), dim_coords_and_dims=[(latitude, 0)])
 
     return cube
@@ -657,14 +715,14 @@ def make_dummy_1d_points_list(num):
     """
         Create a list of 1d points 'num' long
     """
-    return [get_random_1d_point() for i in xrange(0, num)]
+    return [get_random_1d_point() for i in range(0, num)]
 
 
 def make_dummy_2d_points_list(num):
     """
         Create a list of 2d points 'num' long
     """
-    return [get_random_2d_point() for i in xrange(0, num)]
+    return [get_random_2d_point() for i in range(0, num)]
 
 
 def make_dummy_ungridded_data_time_series(len=10):
@@ -674,18 +732,20 @@ def make_dummy_ungridded_data_time_series(len=10):
     :return:
     """
     from datetime import datetime, timedelta
+    from cis.time_util import cis_standard_time_unit
     from cis.data_io.Coord import Coord, CoordList
     from cis.data_io.ungridded_data import UngriddedData, Metadata
 
     t0 = datetime(1984, 8, 27)
-    times = np.array([t0 + timedelta(days=d) for d in xrange(len)])
+    times = np.array([t0 + timedelta(days=d) for d in range(len)])
 
     x = Coord(np.zeros(len) + 65.2, Metadata(standard_name='latitude', units='degrees'))
     y = Coord(np.zeros(len) - 12.1, Metadata(standard_name='longitude', units='degrees'))
-    t = Coord(times, Metadata(standard_name='time', units='DateTime Object'), axis='x')
+    t = Coord(cis_standard_time_unit.date2num(times),
+              Metadata(standard_name='time', units=cis_standard_time_unit), axis='x')
     data = np.arange(len) + 1.0
 
-    return UngriddedData(data, Metadata(standard_name='rain', long_name="TOTAL RAINFALL RATE: LS+CONV KG/M2/S",
+    return UngriddedData(data, Metadata(standard_name='rainfall_flux', long_name="TOTAL RAINFALL RATE: LS+CONV KG/M2/S",
                                         units="kg m-2 s-1", missing_value=-999), CoordList([x, y, t]))
 
 
@@ -764,7 +824,7 @@ def make_dummy_2d_ungridded_data():
     y = Coord(gen_random_lon_array((5, 5)), Metadata('longitude'), 'y')
     coords = CoordList([x, y])
     data = gen_random_data_array((5, 5), 4.0, 1.0)
-    return UngriddedData(data, Metadata(standard_name='rain', long_name="TOTAL RAINFALL RATE: LS+CONV KG/M2/S",
+    return UngriddedData(data, Metadata(standard_name='rainfall_flux', long_name="TOTAL RAINFALL RATE: LS+CONV KG/M2/S",
                                         units="kg m-2 s-1", missing_value=-999), coords)
 
 
@@ -811,8 +871,8 @@ def make_regular_2d_ungridded_data(lat_dim_length=5, lat_min=-10, lat_max=10, lo
     y_points = np.linspace(lon_min, lon_max, lon_dim_length)
     y, x = np.meshgrid(y_points, x_points)
 
-    x = Coord(x, Metadata(name='lat', standard_name='latitude', units='degrees'))
-    y = Coord(y, Metadata(name='lon', standard_name='longitude', units='degrees'))
+    x = Coord(x, Metadata(name='lat', standard_name='latitude', units='degrees'), axis='Y')
+    y = Coord(y, Metadata(name='lon', standard_name='longitude', units='degrees'), axis= 'X')
     data = np.reshape(np.arange(lat_dim_length * lon_dim_length) + data_offset + 1.0, (lat_dim_length, lon_dim_length))
     if mask:
         data = np.ma.asarray(data)
@@ -907,7 +967,7 @@ def make_regular_2d_with_time_ungridded_data():
     y, x = np.meshgrid(y_points, x_points)
 
     t0 = datetime.datetime(1984, 8, 27)
-    times = np.reshape(np.array([t0 + datetime.timedelta(days=d) for d in xrange(15)]), (5, 3))
+    times = np.reshape(np.array([t0 + datetime.timedelta(days=d) for d in range(15)]), (5, 3))
 
     x = Coord(x, Metadata(standard_name='latitude', units='degrees'))
     y = Coord(y, Metadata(standard_name='longitude', units='degrees'))
@@ -916,7 +976,7 @@ def make_regular_2d_with_time_ungridded_data():
     data = np.reshape(np.arange(15) + 1.0, (5, 3))
 
     coords = CoordList([x, y, t])
-    return UngriddedData(data, Metadata(standard_name='rain', long_name="TOTAL RAINFALL RATE: LS+CONV KG/M2/S",
+    return UngriddedData(data, Metadata(name='rain', standard_name='rainfall_flux', long_name="TOTAL RAINFALL RATE: LS+CONV KG/M2/S",
                                         units="kg m-2 s-1", missing_value=-999), coords)
 
 
@@ -938,7 +998,7 @@ def make_MODIS_time_steps():
     data = np.arange(4.0)
 
     coords = CoordList([x, t])
-    return UngriddedData(data, Metadata(standard_name='rain', long_name="TOTAL RAINFALL RATE: LS+CONV KG/M2/S",
+    return UngriddedData(data, Metadata(standard_name='rainfall_flux', long_name="TOTAL RAINFALL RATE: LS+CONV KG/M2/S",
                                         units="kg m-2 s-1", missing_value=-999), coords)
 
 
@@ -1029,7 +1089,7 @@ def make_regular_4d_ungridded_data():
     x_points = np.linspace(-10, 10, 5)
     y_points = np.linspace(-5, 5, 5)
     t0 = datetime.datetime(1984, 8, 27)
-    times = convert_datetime_to_std_time(np.array([t0 + datetime.timedelta(days=d) for d in xrange(5)]))
+    times = convert_datetime_to_std_time(np.array([t0 + datetime.timedelta(days=d) for d in range(5)]))
 
     alt = np.linspace(0, 90, 10)
 
@@ -1046,10 +1106,10 @@ def make_regular_4d_ungridded_data():
     x = Coord(x, Metadata(standard_name='latitude', units='degrees'))
     y = Coord(y, Metadata(standard_name='longitude', units='degrees'))
     p = Coord(p, Metadata(standard_name='air_pressure', units='Pa'))
-    t = Coord(t, Metadata(standard_name='time', units=str(cis_standard_time_unit)))
+    t = Coord(t, Metadata(standard_name='time', units=cis_standard_time_unit))
 
     coords = CoordList([x, y, a, p, t])
-    return UngriddedData(data, Metadata(standard_name='rain', long_name="TOTAL RAINFALL RATE: LS+CONV KG/M2/S",
+    return UngriddedData(data, Metadata(standard_name='rainfall_flux', long_name="TOTAL RAINFALL RATE: LS+CONV KG/M2/S",
                                         units="kg m-2 s-1", missing_value=-999), coords)
 
 
